b\_rabbit package
=================

Submodules
----------

b\_rabbit.b\_rabbit module
--------------------------

.. automodule:: b_rabbit.b_rabbit
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: b_rabbit
    :members:
    :undoc-members:
    :show-inheritance:
